@@ -60,6 +60,7 @@ function make_hidden($post, &$tag)
     /* ֤ͤѿ */
     $loggroup   = $post["loggroup"];
     $priority   = $post["priority"];
+    $hostname   = escape_html($post["hostname"]);
     $keyword    = escape_html($post["keyword"]);
     $searchtype = $post["searchtype"];
     $start      = $post["startdate"];
@@ -73,6 +74,7 @@ function make_hidden($post, &$tag)
   <input type="hidden" name="page">
   <input type="hidden" name="loggroup" value="$loggroup">
   <input type="hidden" name="priority" value="$priority">
+  <input type="hidden" name="hostname" value="$hostname">
   <input type="hidden" name="keyword" value="$keyword">
   <input type="hidden" name="searchtype" value="$searchtype">
   <input type="hidden" name="startdate" value="$start">
