@@ -59,6 +59,8 @@ define("MAIL_SEARCH_SQL",   "SELECT DeviceReportedTime, FromHost, Message " .
  **********************************************************/
 function set_tag_data($post, &$tag)
 {
+    global $web_conf;
+
     /*24դ*/
     $daylist = getdate(time() - 86400);
 
@@ -112,64 +114,20 @@ EOD;
     }
     $tag["<<TO_RULE>>"] = make_checked_list($list);
 
-    /* ϻ֥쥯ȥܥå */
-    $option = array("0" => "",
-                    "1" => "",
-                    "2" => "",
-                    "3" => "",
-                    "4" => "",
-                    "5" => ""
-                   );
-    if (isset($post["starttime"])) {
-        $starttime =$post["starttime"];
-    } else {
-
-        /*24λ֤򥻥å*/
-        $starttime = array("0" => strval($daylist["year"]),
-                           "1" => strval($daylist["mon"]),
-                           "2" => strval($daylist["mday"]),
-                           "3" => strval($daylist["hours"]),
-                           "4" => strval($daylist["minutes"]),
-                           "5" => strval($daylist["seconds"])
-                          );
+    $tag["<<STARTDATE>>"] = date("Y/m/d 00:00:00");
+    if (isset($_POST["startdate"]) === TRUE) {
+        $tag["<<STARTDATE>>"] = $_POST["startdate"];
     }
 
-    make_time_select_option($starttime, $option);
-    $tag["<<START_YEAR_OPTION>>"]   = $option["0"];
-    $tag["<<START_MONTH_OPTION>>"]  = $option["1"];
-    $tag["<<START_DATE_OPTION>>"]   = $option["2"];
-    $tag["<<START_HOUR_OPTION>>"]   = $option["3"];
-    $tag["<<START_MINUTE_OPTION>>"] = $option["4"];
-    $tag["<<START_SECOND_OPTION>>"] = $option["5"];
+    $tag["<<ENDDATE>>"] = date("Y/m/d 23:59:59");
+    if (isset($_POST["enddate"]) === TRUE) {
+        $tag["<<ENDDATE>>"] = $_POST["enddate"];
+    }
 
-    /* λ֤Υ쥯ȥܥå */
-    $option = array("0" => "",
-                    "1" => "",
-                    "2" => "",
-                    "3" => "",
-                    "4" => "",
-                    "5" => ""
-                   );
-    if (isset($post["endtime"])) {
-        $endtime =$post["endtime"];
- } else {
-
-        /*--ǯ--------ʬ--äɽ*/
-        $endtime = array("0" => -2,
-                         "1" => -2,
-                         "2" => -2,
-                         "3" => -2,
-                         "4" => -2,
-                         "5" => -2
-                        );
+    $tag["<<DEFLINE>>"] = $web_conf["sylas"]["displaylines"];
+    if (isset($_POST["resultline"])) {
+        $tag["<<DEFLINE>>"] = $_POST["resultline"];
     }
-    make_time_select_option($endtime, $option);
-    $tag["<<END_YEAR_OPTION>>"]     = $option["0"];
-    $tag["<<END_MONTH_OPTION>>"]    = $option["1"];
-    $tag["<<END_DATE_OPTION>>"]     = $option["2"];
-    $tag["<<END_HOUR_OPTION>>"]     = $option["3"];
-    $tag["<<END_MINUTE_OPTION>>"]   = $option["4"];
-    $tag["<<END_SECOND_OPTION>>"]   = $option["5"];
 
     return TRUE;
 }
@@ -193,20 +151,9 @@ function make_hidden($post, &$tag)
     $loggroup   = $post["loggroup"];
     $sendaddr   = escape_html($post["sendaddr"]);
     $reciveaddr   = escape_html($post["reciveaddr"]);
-    $start      = $post["starttime"];
-    $end        = $post["endtime"];
-    $s_year     = $start[0];
-    $s_month    = $start[1];
-    $s_date     = $start[2];
-    $s_hour     = $start[3];
-    $s_minute   = $start[4];
-    $s_second   = $start[5];
-    $e_year     = $end[0];
-    $e_month    = $end[1];
-    $e_date     = $end[2];
-    $e_hour     = $end[3];
-    $e_minute   = $end[4];
-    $e_second   = $end[5];
+    $start      = $post["startdate"];
+    $end        = $post["enddate"];
+    $resultline = $post["resultline"];
     $sesskey    = escape_html($post["sk"]);
 
     /*hidden*/
@@ -216,19 +163,10 @@ function make_hidden($post, &$tag)
   <input type="hidden" name="loggroup" value="$loggroup">
   <input type="hidden" name="sendaddr" value="$sendaddr">
   <input type="hidden" name="reciveaddr" value="$reciveaddr">
-  <input type="hidden" name="starttime[0]" value="$s_year">
-  <input type="hidden" name="starttime[1]" value="$s_month">
-  <input type="hidden" name="starttime[2]" value="$s_date">
-  <input type="hidden" name="starttime[3]" value="$s_hour">
-  <input type="hidden" name="starttime[4]" value="$s_minute">
-  <input type="hidden" name="starttime[5]" value="$s_second">
-  <input type="hidden" name="endtime[0]" value="$e_year">
-  <input type="hidden" name="endtime[1]" value="$e_month">
-  <input type="hidden" name="endtime[2]" value="$e_date">
-  <input type="hidden" name="endtime[3]" value="$e_hour">
-  <input type="hidden" name="endtime[4]" value="$e_minute">
-  <input type="hidden" name="endtime[5]" value="$e_second">
+  <input type="hidden" name="startdate" value="$start">
+  <input type="hidden" name="enddate" value="$end">
   <input type="hidden" name="sk" value="$sesskey">
+  <input type="hidden" name="resultline" value="$resultline">
   <input type="hidden" name="next_button" value="search">
 </form>
     
@@ -258,8 +196,9 @@ function set_loop_tag($page, &$looptag, $sesskey, $post)
     global $web_conf;
 
     /* 롼ץ */
-    $start = ($page - 1) * $web_conf['sylas']['displaylines'];
-    $end   = ($web_conf['sylas']['displaylines'] - 1) + $start;
+    $start = ($page - 1) * $_POST["resultline"];
+    $end   = ($page * $_POST["resultline"]) - 1;
+
     $k = 0; 
 
     for ( ; $start <= $end ; $start++) {
@@ -274,51 +213,25 @@ function set_loop_tag($page, &$looptag, $sesskey, $post)
         $looptag[$k]["<<LOG_FROM>>"] = $_SESSION["result"][$start]["from"];
         $looptag[$k]["<<LOG_TO>>"] = $_SESSION["result"][$start]["to"];
         $looptag[$k]["<<LOG_STATUS>>"] = $_SESSION["result"][$start]["status"];
+        $looptag[$k]["<<RL>>"] = $web_conf["sylas"]["displaylines"];
 
         /*ܺ٥ܥ*/
         $looptag[$k]["<<MORE>>"] =  "<button class=\"mail_button\" type=\"submit\" name=\"more\" value=\"".$k."\">ܺ</button>";
         $looptag[$k]["<<E_SESS>>"] = $sesskey;
 
         /*QIDå*/
+
         if (strpos($_SESSION["result"][$start]["qid"], "NOQUEUE") === FALSE) {
-            $looptag[$k]["<<S_SY>>"] = "--";
-            $looptag[$k]["<<S_SM>>"] = "--";
-            $looptag[$k]["<<S_SD>>"] = "--";
-            $looptag[$k]["<<S_SH>>"] = "--";
-            $looptag[$k]["<<S_SMI>>"] = "--";
-            $looptag[$k]["<<S_SS>>"] = "--";
-                
-            $looptag[$k]["<<E_SY>>"] = "--";
-            $looptag[$k]["<<E_SM>>"] = "--";
-            $looptag[$k]["<<E_SD>>"] = "--";
-            $looptag[$k]["<<E_SH>>"] = "--";
-            $looptag[$k]["<<E_SMI>>"] = "--";
-            $looptag[$k]["<<E_SS>>"] = "--";
+            $sdate = date("Y/m/d H:i:s", strtotime($log_date. " -1 day"));
+            $edate = date("Y/m/d H:i:s", strtotime($log_date. " +1 day"));
+
+            $looptag[$k]["<<S_D>>"] = $sdate;
+            $looptag[$k]["<<E_D>>"] = $edate;
             $looptag[$k]["<<QID>>"] = $_SESSION["result"][$start]["qid"]. ":";
         } else {
-
-            $half_date = explode(" ", $log_date);
-            $half_date2 = explode("-", $half_date[0]);
-            $half_time = explode(":", $half_date[1]);
-            $s_year = preg_replace("/^0/", "", $half_date2[0]); 
-            $s_mon = preg_replace("/^0/", "", $half_date2[1]);
-            $s_day = preg_replace("/^0/", "", $half_date2[2]);
-            $s_hour = preg_replace("/^0/", "", $half_time[0]);
-            $s_min = preg_replace("/^0/", "", $half_time[1]);
-            $s_sec = preg_replace("/^0/", "", $half_time[2]);
-
-            $looptag[$k]["<<S_SY>>"] = $s_year;
-            $looptag[$k]["<<S_SM>>"] = $s_mon;
-            $looptag[$k]["<<S_SD>>"] = $s_day;
-            $looptag[$k]["<<S_SH>>"] = $s_hour;
-            $looptag[$k]["<<S_SMI>>"] = $s_min;
-            $looptag[$k]["<<S_SS>>"] = $s_sec;
-            $looptag[$k]["<<E_SY>>"] = $s_year;
-            $looptag[$k]["<<E_SM>>"] = $s_mon;
-            $looptag[$k]["<<E_SD>>"] = $s_day;
-            $looptag[$k]["<<E_SH>>"] = $s_hour;
-            $looptag[$k]["<<E_SMI>>"] = $s_min;
-            $looptag[$k]["<<E_SS>>"] = $s_sec;
+            $date = preg_replace("/-/", "/", $log_date);
+            $looptag[$k]["<<S_D>>"] = $date;
+            $looptag[$k]["<<E_D>>"] = $date;
             $looptag[$k]["<<QID>>"] = "NOQUEUE";
         }
         $looptag[$k]["<<HOSTNAME>>"] = $_SESSION["result"][$start]["host"];
@@ -501,43 +414,44 @@ function check_mail_search_condition($post)
 
     /*֤Υå*/
     /**/
-    if (isset($post["starttime"])) {
-        $start_arr = $post["starttime"];
-    } else {
+    if (!isset($post["startdate"])) {
         $err_msg = $msgarr['41008'][SCREEN_MSG];
         return FALSE;
     }
-    $ret = check_time_format($start_arr, START);
+
+    $ret = check_time_format($post["startdate"]);
     if ($ret === FALSE) {
         $err_msg = $msgarr['41008'][SCREEN_MSG];
         return FALSE;
     }
+
     /*λ*/
-    if (isset($post["endtime"])) {
-        $end_arr = $post["endtime"];
-    } else {
+    if (!isset($post["enddate"])) {
         $err_msg = $msgarr['41009'][SCREEN_MSG];
         return FALSE;
     }
-    $ret = check_time_format($end_arr, END);
+
+    $ret = check_time_format($post["enddate"]);
     if ($ret === FALSE) {
         $err_msg = $msgarr['41009'][SCREEN_MSG];
         return FALSE;
     }
 
     /* ϤȽλå */
-    $start = "";
-    $end   = "";
-
-    set_default_time($start_arr, $end_arr, $start, $end);
-
+    $start = strtotime($post["startdate"]);
+    $end   = strtotime($post["enddate"]);
     if ($start > $end) {
         $err_msg = $msgarr['28018'][SCREEN_MSG];
         $log_msg = $msgarr['28018'][LOG_MSG];
         return FALSE;
     }
 
-    $ret = check_duration($start_arr, $end_arr);
+    $ret = check_duration($post["startdate"], $post["enddate"]);
+    if ($ret === FALSE) {
+        return FALSE;
+    }
+
+    $ret = check_resultline($post);
     if ($ret === FALSE) {
         return FALSE;
     }
@@ -878,73 +792,8 @@ function make_mail_search_sql($post, &$sql, $conn)
    }
 
     /* ־ʬ */
-    $start_arr = $post["starttime"];
-    $end_arr = $post["endtime"];
-    /*ϤȽλå*/
-    /*ǯꤵƤʤȤ*/
-    if ($start_arr[0] !== "--") {
-        /*ꤵƤʤ*/
-        if ($start_arr[1] === "--") {
-            $start_arr[1] = 1;
-        }
-
-        /*ꤵƤʤ*/
-        if ($start_arr[2] === "--") { 
-             $start_arr[2] = 1;
-        }
-
-        /*ꤵƤʤ*/
-        if ($start_arr[3] === "--") { 
-            $start_arr[3] = 0;
-        }
-
-        /*ʬꤵƤʤ*/
-        if ($start_arr[4] === "--") { 
-            $start_arr[4] = 0;
-        }
-
-        /*äꤵƤʤ*/
-        if ($start_arr[5] === "--") { 
-            $start_arr[5] = 0;
-        }
-        $start = sprintf("DeviceReportedTime >= \"%04d%02d%02d%02d%02d%02d\"", $start_arr[0], $start_arr[1], $start_arr[2], $start_arr[3], $start_arr[4], $start_arr[5]);
-    } 
-
-    /*λǯꤵƤʤȤ*/
-    if ($end_arr[0] !== "--") {
-        /*ꤵƤʤ*/
-        if ($end_arr[1] === "--") {
-            $end_arr[1] = 12;
-        }
-
-        /*ꤵƤʤ*/
-        if ($end_arr[2] === "--") {
-            $end_arr[2] = date("t", strtotime($end_arr[0]. "-" .$end_arr[1]));
-        }
-
-        /*ꤵƤʤ*/
-        if ($end_arr[3] === "--") { 
-            $end_arr[3] = 23;
-        }
-
-        /*ʬꤵƤʤ*/
-        if ($end_arr[4] === "--") { 
-            $end_arr[4] = 59;
-        }
-
-        /*äꤵƤʤ*/
-        if ($end_arr[5] === "--") { 
-            $end_arr[5] = 59;
-        }
-        $end = sprintf("DeviceReportedTime <= \"%04d%02d%02d%02d%02d%02d\"", $end_arr[0], $end_arr[1], $end_arr[2], $end_arr[3], $end_arr[4], $end_arr[5]);
-    }
-    if ($start_arr[0] === "--" && $end_arr[0] !== "--") {
-        $tmp_sql .= " WHERE " . $end;
-    } elseif ($start_arr[0] !== "--" && $end_arr[0] === "--") {
-        $tmp_sql .= " WHERE " . $start;
-    } elseif ($start_arr[0] !== "--" && $end_arr[0] !== "--") {
-        $tmp_sql .= " WHERE " . $start . " AND " . $end;
-    }
+    make_timerange_sql($conn, $post, $timerange_sql);
+    $tmp_sql = "WHERE ". $timerange_sql;
 
     /*եƥ*/
     /* եƥʸ󤫤ֹѴ
@@ -1020,7 +869,7 @@ function get_mailpage($data_count, $page, &$tag)
     /* =====  ===== */
 
     /* ڡ */
-    $all_page = ceil($data_count / $web_conf["sylas"]["displaylines"]);
+    $all_page = ceil($data_count / $_POST["resultline"]);
     if ($all_page === 0) {
         $all_page = 1;
     }
